Module dispatch

Module dispatch 

Hybrid Summation Dispatch — Routes reductions to the appropriate accumulator.

Dispatch Rules

ConditionStrategy
ExecMode::ParallelBinnedAccumulator
@nogc contextBinnedAccumulator
ReproMode::StrictBinnedAccumulator
Reduction inside LinalgOpBinnedAccumulator
Serial + ReproMode::OnKahan Summation
Serial + no vectorizationKahan Summation
Not forced strictKahan Summation

The dispatch path is deterministic and unit-tested.

Structs

ReductionContext
Reduction context passed to the dispatch logic.

Enums

ExecMode
Execution mode for the current context.
ReproMode
Reproducibility mode.
SumStrategy
Which summation strategy to use.

Functions

dispatch_dot_f64
Dot product of two equal-length f64 slices using dispatched summation.
dispatch_sum_f64
Sum f64 values using the strategy appropriate for the given context.
select_strategy
Determine the appropriate summation strategy for the given context.