pub struct ArenaStore {
pub arena: FrameArena,
/* private fields */
}Expand description
Arena-backed object store. Combines FrameArena with a typed entry list for objects that need to be accessed by index.
Fields
arena: FrameArenaThe underlying bump arena (tracks memory pages).
Implementations
Sourceimpl ArenaStore
impl ArenaStore
pub fn new() -> Self
Sourcepub fn alloc<T: Any + 'static>(&mut self, value: T) -> usize
pub fn alloc<T: Any + 'static>(&mut self, value: T) -> usize
Allocate a new entry in the arena store.
Sourcepub fn get<T: Any + 'static>(&self, index: usize) -> Option<&T>
pub fn get<T: Any + 'static>(&self, index: usize) -> Option<&T>
Get a reference to the stored value at the given index.
Sourcepub fn live_count(&self) -> usize
pub fn live_count(&self) -> usize
Number of live entries.