Sparse eigenvalue solvers (Lanczos, Arnoldi). Sparse Eigenvalue Solvers — Lanczos and Arnoldi
Deterministic sparse eigenvalue extraction for symmetric (Lanczos) and general (Arnoldi) matrices. All operations use Kahan summation for order-invariant deterministic reductions.
Structs
- Arnoldi
Result - Result of an Arnoldi eigenvalue computation for a general (non-symmetric) sparse matrix.
- Lanczos
Result - Result of a Lanczos eigenvalue computation.
Functions
- arnoldi_
eigs - Compute eigenvalue approximations of a general sparse matrix using the Arnoldi iteration to build an upper Hessenberg matrix, then extract eigenvalues from the Hessenberg form.
- lanczos_
eigsh - Compute the
klargest eigenvalues of a symmetric sparse matrix using the Lanczos algorithm.