pub fn dispatch_sum_f64(values: &[f64], ctx: &ReductionContext) -> f64Expand description
Sum f64 values using the strategy appropriate for the given context.
This is the primary entry point for all reductions in the CJC runtime.
pub fn dispatch_sum_f64(values: &[f64], ctx: &ReductionContext) -> f64Sum f64 values using the strategy appropriate for the given context.
This is the primary entry point for all reductions in the CJC runtime.